--[[
Name: Babble-Zone-2.2
Revision: $Rev: 28865 $
Author(s): ckknight (ckknight@gmail.com)
Website: http://ckknight.wowinterface.com/
Documentation: http://wiki.wowace.com/index.php/Babble-Zone-2.2
SVN: http://svn.wowace.com/root/trunk/Babble-2.2/Babble-Zone-2.2
Description: A library to provide localizations for zones.
Dependencies: AceLibrary, AceLocale-2.2
License: MIT
]]

local MAJOR_VERSION = "Babble-Zone-2.2"
local MINOR_VERSION = tonumber(string.sub("$Revision: 28865 $", 12, -3))

if not AceLibrary then error(MAJOR_VERSION .. " requires AceLibrary") end

if not AceLibrary:HasInstance("AceLocale-2.2") then error(MAJOR_VERSION .. " requires AceLocale-2.2") end

local _, x = AceLibrary("AceLocale-2.2"):GetLibraryVersion()
MINOR_VERSION = MINOR_VERSION * 100000 + x

if not AceLibrary:IsNewVersion(MAJOR_VERSION, MINOR_VERSION) then return end

local BabbleZone = AceLibrary("AceLocale-2.2"):new(MAJOR_VERSION)

-- uncomment below for debug information
-- BabbleZone:EnableDebugging()

BabbleZone:RegisterTranslations("enUS", function()
	return {
		["Azeroth"] = true,
		["Eastern Kingdoms"] = true,
		["Kalimdor"] = true,
		["Outland"] = true,
		["Cosmic map"] = true,
		
		["Ahn'Qiraj"] = true,
		["Alterac Mountains"] = true,
		["Alterac Valley"] = true,
		["Arathi Basin"] = true,
		["Arathi Highlands"] = true,
		["Ashenvale"] = true,
		["Auberdine"] = true,
		["Azshara"] = true,
		["Badlands"] = true,
		["The Barrens"] = true,
		["Blackfathom Deeps"] = true,
		["Blackrock Depths"] = true,
		["Blackrock Mountain"] = true,
		["Blackrock Spire"] = true,
		["Blackwing Lair"] = true,
		["Blasted Lands"] = true,
		["Booty Bay"] = true,
		["Burning Steppes"] = true,
		["Darkshore"] = true,
		["Darnassus"] = true,
		["The Deadmines"] = true,
		["Deadwind Pass"] = true,
		["Deeprun Tram"] = true,
		["Desolace"] = true,
		["Dire Maul"] = true,
		["Dire Maul (East)"] = true,
		["Dire Maul (West)"] = true,
		["Dire Maul (North)"] = true,
		["Dun Morogh"] = true,
		["Durotar"] = true,
		["Duskwood"] = true,
		["Dustwallow Marsh"] = true,
		["Eastern Plaguelands"] = true,
		["Elwynn Forest"] = true,
		["Everlook"] = true,
		["Felwood"] = true,
		["Feralas"] = true,
		["The Forbidding Sea"] = true,
		["Gadgetzan"] = true,
		["Gates of Ahn'Qiraj"] = true,
		["Gnomeregan"] = true,
		["The Great Sea"] = true,
		["Grom'gol Base Camp"] = true,
		["Hall of Legends"] = true,
		["Hillsbrad Foothills"] = true,
		["The Hinterlands"] = true,
		["Hyjal"] = true,
		["Ironforge"] = true,
		["Loch Modan"] = true,
		["Lower Blackrock Spire"] = true,
		["Maraudon"] = true,
		["Menethil Harbor"] = true,
		["Molten Core"] = true,
		["Moonglade"] = true,
		["Mulgore"] = true,
		["Naxxramas"] = true,
		["Onyxia's Lair"] = true,
		["Orgrimmar"] = true,
		["Ratchet"] = true,
		["Ragefire Chasm"] = true,
		["Razorfen Downs"] = true,
		["Razorfen Kraul"] = true,
		["Redridge Mountains"] = true,
		["Ruins of Ahn'Qiraj"] = true,
		["Scarlet Monastery"] = true,
		["Scholomance"] = true,
		["Searing Gorge"] = true,
		["Shadowfang Keep"] = true,
		["Silithus"] = true,
		["Silverpine Forest"] = true,
		["The Stockade"] = true,
		["Stonetalon Mountains"] = true,
		["Stormwind City"] = true,
		["Stranglethorn Vale"] = true,
		["Stratholme"] = true,
		["Swamp of Sorrows"] = true,
		["Tanaris"] = true,
		["Teldrassil"] = true,
		["Temple of Ahn'Qiraj"] = true,
		["The Temple of Atal'Hakkar"] = true,
		["Theramore Isle"] = true,
		["Thousand Needles"] = true,
		["Thunder Bluff"] = true,
		["Tirisfal Glades"] = true,
		["Uldaman"] = true,
		["Un'Goro Crater"] = true,
		["Undercity"] = true,
		["Upper Blackrock Spire"] = true,
		["Wailing Caverns"] = true,
		["Warsong Gulch"] = true,
		["Western Plaguelands"] = true,
		["Westfall"] = true,
		["Wetlands"] = true,
		["Winterspring"] = true,
		["Zul'Farrak"] = true,
		["Zul'Gurub"] = true,

		["Champions' Hall"] = true,
		["Blade's Edge Arena"] = true,
		["Nagrand Arena"] = true,
		["Twisting Nether"] = true,
		["The Veiled Sea"] = true,
		["The North Sea"] = true,

		-- Burning Crusade
		
		-- Subzones used for displaying instances.
		["Plaguewood"] = true,
		["Hellfire Citadel"] = true,
		["Auchindoun"] = true,
		["The Bone Wastes"] = true, -- Substitute for Auchindoun, since this is what shows on the minimap.
		["Ring of Observance"] = true,
		["Coilfang Reservoir"] = true,

		["Azuremyst Isle"] = true,
		["Bloodmyst Isle"] = true,
		["Eversong Woods"] = true,
		["Ghostlands"] = true,
		["The Exodar"] = true,
		["Silvermoon City"] = true,
		["Shadowmoon Valley"] = true,
		["Black Temple"] = true,
		["Terokkar Forest"] = true,
		["Auchenai Crypts"] = true,
		["Mana-Tombs"] = true,
		["Shadow Labyrinth"] = true,
		["Sethekk Halls"] = true,
		["Hellfire Peninsula"] = true,
		["The Dark Portal"] = true,
		["Hellfire Ramparts"] = true,
		["The Blood Furnace"] = true,
		["The Shattered Halls"] = true,
		["Magtheridon's Lair"] = true,
		["Nagrand"] = true,
		["Zangarmarsh"] = true,
		["The Slave Pens"] = true,
		["The Underbog"] = true,
		["The Steamvault"] = true,
		["Serpentshrine Cavern"] = true,
		["Blade's Edge Mountains"] = true,
		["Gruul's Lair"] = true,
		["Netherstorm"] = true,
		["Tempest Keep"] = true,
		["The Mechanar"] = true,
		["The Botanica"] = true,
		["The Arcatraz"] = true,
		["The Eye"] = true,
		["Eye of the Storm"] = true,
		["Shattrath City"] = true,
		["Karazhan"] = true,
		["Caverns of Time"] = true,
		["Old Hillsbrad Foothills"] = true,
		["The Black Morass"] = true,
		["The Battle for Mount Hyjal"] = true, -- check
		["Zul'Aman"] = true,
	}
end)

BabbleZone:RegisterTranslations("deDE", function()
	return {
		["Azeroth"] = "Azeroth",
		["Eastern Kingdoms"] = "\195\150stliche K\195\182nigreiche",
		["Kalimdor"] = "Kalimdor",
		["Outland"] = "Scherbenwelt",
		["Cosmic map"] = "Kosmische Karte",
		
		["Ahn'Qiraj"] = "Ahn'Qiraj",
		["Alterac Mountains"] = "Alteracgebirge",
		["Alterac Valley"] = "Alteractal",
		["Arathi Basin"] = "Arathibecken",
		["Arathi Highlands"] = "Arathihochland",
		["Ashenvale"] = "Eschental",
		["Auberdine"] = "Auberdine",
		["Azshara"] = "Azshara",
		["Badlands"] = "\195\150dland",
		["The Barrens"] = "Brachland",
		["Blackfathom Deeps"] = "Tiefschwarze Grotte",
		["Blackrock Depths"] = "Schwarzfelstiefen",
		["Blackrock Mountain"] = "Der Schwarzfels",
		["Blackrock Spire"] = "Schwarzfelsspitze",
		["Blackwing Lair"] = "Pechschwingenhort",
		["Blasted Lands"] = "Verw\195\188stete Lande",
		["Booty Bay"] = "Beutebucht",
		["Burning Steppes"] = "Brennende Steppe",
		["Darkshore"] = "Dunkelk\195\188ste",
		["Darnassus"] = "Darnassus",
		["The Deadmines"] = "Die Todesminen",
		["Deadwind Pass"] = "Gebirgspass der Totenwinde",
		["Deeprun Tram"] = "Die Tiefenbahn",
		["Desolace"] = "Desolace",
		["Dire Maul"] = "D\195\188sterbruch",
		["Dire Maul (North)"] = "D\195\188sterbruch (Nord)",
		["Dire Maul (East)"] = "D\195\188sterbruch (Ost)",
		["Dire Maul (West)"] = "D\195\188sterbruch (West)",
		["Dun Morogh"] = "Dun Morogh",
		["Durotar"] = "Durotar",
		["Duskwood"] = "D\195\164mmerwald",
		["Dustwallow Marsh"] = "D\195\188stermarschen",
		["Eastern Plaguelands"] = "\195\150stliche Pestl\195\164nder",
		["Elwynn Forest"] = "Wald von Elwynn",
		["Everlook"] = "Ewige Warte",
		["Felwood"] = "Teufelswald",
		["Feralas"] = "Feralas",
		["The Forbidding Sea"] = "Das verbotene Meer",
		["Gadgetzan"] = "Gadgetzan",
		["Gates of Ahn'Qiraj"] = "Tore von Ahn'Qiraj",
		["Gnomeregan"] = "Gnomeregan",
		["Grom'gol Base Camp"] = "Basislager von Grom'gol",
		["The Great Sea"] = "Das grosse Meer",
		["Hall of Legends"] = "Halle der Legenden",
		["Hillsbrad Foothills"] = "Vorgebirge des H\195\188gellands",
		["The Hinterlands"] = "Hinterland",
		["Hyjal"] = "Hyjal",
		["Ironforge"] = "Eisenschmiede",
		["Loch Modan"] = "Loch Modan",
		["Lower Blackrock Spire"] = "Untere Schwarzfelsspitze",
		["Maraudon"] = "Maraudon",
		["Menethil Harbor"] = "Hafen von Menethil",
		["Molten Core"] = "Geschmolzener Kern",
		["Moonglade"] = "Mondlichtung",
		["Mulgore"] = "Mulgore",
		["Naxxramas"] = "Naxxramas",
		["Onyxia's Lair"] = "Onyxias Hort",
		["Orgrimmar"] = "Orgrimmar",
		["Ratchet"] = "Ratschet",
		["Ragefire Chasm"] = "Der Flammenschlund",
		["Razorfen Downs"] = "H\195\188gel der Klingenhauer",
		["Razorfen Kraul"] = "Kral der Klingenhauer",
		["Redridge Mountains"] = "Rotkammgebirge",
		["Ruins of Ahn'Qiraj"] = "Ruinen von Ahn'Qiraj",
		["Scarlet Monastery"] = "Das Scharlachrote Kloster",
		["Scholomance"] = "Scholomance",
		["Searing Gorge"] = "Sengende Schlucht",
		["Shadowfang Keep"] = "Burg Schattenfang",
		["Silithus"] = "Silithus",
		["Silverpine Forest"] = "Silberwald",
		["The Stockade"] = "Das Verlies",
		["Stonetalon Mountains"] = "Steinkrallengebirge",
		["Stormwind City"] = "Sturmwind",
		["Stranglethorn Vale"] = "Schlingendorntal",
		["Stratholme"] = "Stratholme",
		["Swamp of Sorrows"] = "S\195\188mpfe des Elends",
		["Tanaris"] = "Tanaris",
		["Teldrassil"] = "Teldrassil",
		["Temple of Ahn'Qiraj"] = "Tempel von Ahn'Qiraj",
		["The Temple of Atal'Hakkar"] = "Der Tempel von Atal'Hakkar",
		["Theramore Isle"] = "Insel Theramore",
		["Thousand Needles"] = "Tausend Nadeln",
		["Thunder Bluff"] = "Donnerfels",
		["Tirisfal Glades"] = "Tirisfal",
		["Uldaman"] = "Uldaman",
		["Un'Goro Crater"] = "Krater von Un'Goro",
		["Undercity"] = "Unterstadt",
		["Upper Blackrock Spire"] = "Obere Schwarzfelsspitze",
		["Wailing Caverns"] = "Die H\195\182hlen des Wehklagens",
		["Warsong Gulch"] = "Kriegshymnenschlucht",
		["Western Plaguelands"] = "Westliche Pestl\195\164nder",
		["Westfall"] = "Westfall",
		["Wetlands"] = "Sumpfland",
		["Winterspring"] = "Winterquell",
		["Zul'Farrak"] = "Zul'Farrak",
		["Zul'Gurub"] = "Zul'Gurub",
		
		["Champions' Hall"] = "Halle der Champions",
		["Blade's Edge Arena"] = "Arena des Schergrats",
		["Nagrand Arena"] = "Arena von Nagrand",
		["Twisting Nether"] = "Wirbelnder Nether",
		["The Veiled Sea"] = "Das verh\195\188llte Meer",
		["The North Sea"] = "Das N\195\182rdliche Meer",

		-- Burning Crusade
		
		-- Subzones used for displaying instances.
		["Plaguewood"] = "Seuchenwald",
		["Hellfire Citadel"] = "H\195\182llenfeuerzitadelle",
		["Auchindoun"] = "Auchindoun",
		["The Bone Wastes"] = "Die Knochenw\195\188ste", -- Substitute for Auchindoun, since this is what shows on the minimap.
		["Ring of Observance"] = "Ring of Observance",
		["Coilfang Reservoir"] = "Echsenkessel",

		["Azuremyst Isle"] = "Azurmythosinsel",
		["Bloodmyst Isle"] = "Blutmythosinsel",
		["Eversong Woods"] = "Immersangwald",
		["Ghostlands"] = "Geisterlande",
		["The Exodar"] = "Die Exodar",
		["Silvermoon City"] = "Silbermond",
		["Shadowmoon Valley"] = "Schattenmondtal",
		["Black Temple"] = "Schwarzer Tempel",
		["Terokkar Forest"] = "W\195\164lder von Terokkar",
		["Auchenai Crypts"] = "Auchenaikrypta",
		["Mana-Tombs"] = "Managruft",
		["Shadow Labyrinth"] = "Schattenlabyrinth",
		["Sethekk Halls"] = "Sethekkhallen",
		["Hellfire Peninsula"] = "H\195\182llenfeuerhalbinsel",
		["The Dark Portal"] = "Das Dunkle Portal",
		["Hellfire Ramparts"] = "H\195\182llenfeuerbollwerk",
		["The Blood Furnace"] = "Der Blutkessel",
		["The Shattered Halls"] = "Die zerschmetterten Hallen",
		["Magtheridon's Lair"] = "Magtheridons Hort",
		["Nagrand"] = "Nagrand",
		["Zangarmarsh"] = "Zangarmarschen",
		["The Slave Pens"] = "Die Sklavenunterk\195\188nfte",
		["The Underbog"] = "Der Tiefensumpf",
		["The Steamvault"] = "Die Dampfkammer",
		["Serpentshrine Cavern"] = "Schlangenschrein H\195\182hle",
		["Blade's Edge Mountains"] = "Schergrat",
		["Gruul's Lair"] = "Gruuls Unterschlupf",
		["Netherstorm"] = "Nethersturm",
		["Tempest Keep"] = "Festung der St\195\188rme",
		["The Mechanar"] = "Mechanar",
		["The Botanica"] = "Botanikum",
		["The Arcatraz"] = "Arkatraz",
		["The Eye"] = "The Eye",
		["Eye of the Storm"] = "Auge des Sturms",
		["Shattrath City"] = "Shattrath",
		["Karazhan"] = "Karazhan",
		["Caverns of Time"] = "Die H\195\182hlen der Zeit",
		["Old Hillsbrad Foothills"] = "Vorgebirge des Alten H\195\188gellands",
		["The Black Morass"] = "Der schwarze Morast",
		["The Battle for Mount Hyjal"] = "Die Schlacht um den Berg Hyjal", -- check
		["Zul'Aman"] = "Zul'Aman",
	}
end)

BabbleZone:RegisterTranslations("frFR", function()
	return {
		["Azeroth"] = "Azeroth",
		["Eastern Kingdoms"] = "Royaumes de l'est",
		["Kalimdor"] = "Kalimdor",
		["Outland"] = "Outreterre",
		["Cosmic map"] = "Carte cosmique",
		
		["Ahn'Qiraj"] = "Ahn'Qiraj",
		["Alterac Mountains"] = "Montagnes d'Alterac",
		["Alterac Valley"] = "Vall\195\169e d'Alterac",
		["Arathi Basin"] = "Bassin d'Arathi",
		["Arathi Highlands"] = "Hautes-terres d'Arathi",
		["Ashenvale"] = "Orneval",
		["Auberdine"] = "Auberdine",
		["Azshara"] = "Azshara",
		["Badlands"] = "Terres ingrates",
		["The Barrens"] = "Les Tarides",
		["Blackfathom Deeps"] = "Profondeurs de Brassenoire",
		["Blackrock Depths"] = "Profondeurs de Rochenoire",
		["Blackrock Mountain"] = "Mont Rochenoire",
		["Blackrock Spire"] = "Pic Rochenoire",
		["Blackwing Lair"] = "Repaire de l'Aile noire",
		["Blasted Lands"] = "Terres foudroy\195\169es",
		["Booty Bay"] = "Baie-du-Butin",
		["Burning Steppes"] = "Steppes ardentes",
		["Darkshore"] = "Sombrivage",
		["Darnassus"] = "Darnassus",
		["The Deadmines"] = "Les mortemines",
		["Deadwind Pass"] = "D\195\169fil\195\169 de Deuillevent",
		["Deeprun Tram"] = "Tram des profondeurs",
		["Desolace"] = "D\195\169solace",
		["Dire Maul"] = "Hache-tripes",
		["Dire Maul (East)"] = "Hache-tripes (Est)",
		["Dire Maul (West)"] = "Hache-tripes (Ouest)",
		["Dire Maul (North)"] = "Hache-tripes (Nord)",
		["Dun Morogh"] = "Dun Morogh",
		["Durotar"] = "Durotar",
		["Duskwood"] = "Bois de la P\195\169nombre",
		["Dustwallow Marsh"] = "Mar\195\169cage d'\195\130prefange",
		["Eastern Plaguelands"] = "Maleterres de l'est",
		["Elwynn Forest"] = "For\195\170t d'Elwynn",
		["Everlook"] = "Long-guet",
		["Felwood"] = "Gangrebois",
		["Feralas"] = "F\195\169ralas",
		["The Forbidding Sea"] = "La Mer interdite",
		["Gadgetzan"] = "Gadgetzan",
		["Gates of Ahn'Qiraj"] = "Portes d'Ahn'Qiraj",
		["Gnomeregan"] = "Gnomeregan",
		["Grom'gol Base Camp"] = "Campement Grom'gol",
		["The Great Sea"] = "La Grande mer",
		["Hall of Legends"] = "Hall des L\195\169gendes",
		["Hillsbrad Foothills"] = "Contreforts de Hautebrande",
		["The Hinterlands"] = "Les Hinterlands",
		["Hyjal"] = "Hyjal",
		["Ironforge"] = "Forgefer",
		["Loch Modan"] = "Loch Modan",
		["Lower Blackrock Spire"] = "Pic de Rochenoire inf\195\169rieur",
		["Maraudon"] = "Maraudon",
		["Menethil Harbor"] = "Port de Menethil",
		["Molten Core"] = "C\197\147ur du Magma",
		["Moonglade"] = "Reflet-de-Lune",
		["Mulgore"] = "Mulgore",
		["Onyxia's Lair"] = "Repaire d'Onyxia",
		["Naxxramas"] = "Naxxramas",
		["Orgrimmar"] = "Orgrimmar",
		["Ratchet"] = "Cabestan",
		["Ragefire Chasm"] = "Gouffre de Ragefeu",
		["Razorfen Downs"] = "Souilles de Tranchebauge",
		["Razorfen Kraul"] = "Kraal de Tranchebauge",
		["Redridge Mountains"] = "Les Carmines",
		["Ruins of Ahn'Qiraj"] = "Ruines d'Ahn'Qiraj",
		["Scarlet Monastery"] = "Monast\195\168re \195\169carlate",
		["Scholomance"] = "Scholomance",
		["Searing Gorge"] = "Gorge des Vents br\195\187lants",
		["Shadowfang Keep"] = "Donjon d'Ombrecroc",
		["Silithus"] = "Silithus",
		["Silverpine Forest"] = "For\195\170t des Pins argent\195\169s",
		["The Stockade"] = "La Prison",
		["Stonetalon Mountains"] = "Les Serres-Rocheuses",
		["Stormwind City"] = "Hurlevent",
		["Stranglethorn Vale"] = "Vall\195\169e de Strangleronce",
		["Stratholme"] = "Stratholme",
		["Swamp of Sorrows"] = "Marais des Chagrins",
		["Tanaris"] = "Tanaris",
		["Teldrassil"] = "Teldrassil",
		["Temple of Ahn'Qiraj"] = "Le temple d'Ahn'Qiraj",
		["The Temple of Atal'Hakkar"] = "Le temple d'Atal'Hakkar",
		["Theramore Isle"] = "Ile de Theramore",
		["Thousand Needles"] = "Mille pointes",
		["Thunder Bluff"] = "Les Pitons du Tonnerre",
		["Tirisfal Glades"] = "Clairi\195\168res de Tirisfal",
		["Uldaman"] = "Uldaman",
		["Un'Goro Crater"] = "Crat\195\168re d'Un'Goro",
		["Undercity"] = "Fossoyeuse",
		["Upper Blackrock Spire"] = "Pic de Rochenoire sup\195\169rieur",
		["Wailing Caverns"] = "Cavernes des lamentations",
		["Warsong Gulch"] = "Goulet des Chanteguerres",
		["Western Plaguelands"] = "Maleterres de l'ouest",
		["Westfall"] = "Marche de l'Ouest",
		["Wetlands"] = "Les Paluns",
		["Winterspring"] = "Berceau-de-l'Hiver",
		["Zul'Farrak"] = "Zul'Farrak",
		["Zul'Gurub"] = "Zul'Gurub",

		["Champions' Hall"] = "Hall des Champions",
		["Blade's Edge Arena"] = "Ar\195\168ne des Tranchantes",
		["Nagrand Arena"] = "Ar\195\168ne de Nagrand",
		["Twisting Nether"] = "Le N\195\169ant distordu",
		["The Veiled Sea"] = "La Mer voil\195\169e",
--		["The North Sea"] = true,

		-- Burning Crusade

		-- Subzones used for displaying instances.
		["Plaguewood"] = "Pestebois",
		["Hellfire Citadel"] = "Citadelle des flammes infernales",
		["Auchindoun"] = "Auchindoun",
		["The Bone Wastes"] = "Le d\195\169sert des Ossements", -- Substitute for Auchindoun, since this is what shows on the minimap.
		["Ring of Observance"] = "Cercle d'observance",
		["Coilfang Reservoir"] = "R\195\169servoir de Glissecroc",

		["Azuremyst Isle"] = "Ile de Brume-azur",
		["Bloodmyst Isle"] = "Ile de Brume-sang",
		["Eversong Woods"] = "Bois des Chants \195\169ternels",
		["Ghostlands"] = "Les Terres fant\195\180mes",
		["The Exodar"] = "L'Exodar",
		["Silvermoon City"] = "Lune-d'argent",
		["Shadowmoon Valley"] = "Vall\195\169e d'Ombrelune",
		["Black Temple"] = "Le Temple noir",
		["Terokkar Forest"] = "For\195\170t de Terokkar",
		["Auchenai Crypts"] = "Cryptes Auchena\195\175",
		["Mana-Tombs"] = "Tombes-mana",
		["Shadow Labyrinth"] = "Labyrinthe des ombres",
		["Sethekk Halls"] = "Les salles des Sethekk",
		["Hellfire Peninsula"] = "P\195\169ninsule des Flammes infernales",
		["The Dark Portal"] = "La Porte des t\195\169n\195\168bres",
		["Hellfire Ramparts"] = "Remparts des Flammes infernales",
		["The Blood Furnace"] = "La Fournaise du sang",
		["The Shattered Halls"] = "Les Salles bris\195\169es",
		["Magtheridon's Lair"] = "Le repaire de Magtheridon",
		["Nagrand"] = "Nagrand",
		["Zangarmarsh"] = "Mar\195\169cage de Zangar",
		["The Slave Pens"] = "Les enclos aux esclaves",
		["The Underbog"] = "La Basse-tourbi\195\168re",
		["The Steamvault"] = "Le Caveau de la vapeur",
		["Serpentshrine Cavern"] = "Sanctuaire du Serpent",
		["Blade's Edge Mountains"] = "Les Tranchantes",
		["Gruul's Lair"] = "Repaire de Gruul",
		["Netherstorm"] = "Raz-de-N\195\169ant",
		["Tempest Keep"] = "Donjon de la Temp\195\170te",
		["The Mechanar"] = "Le M\195\169chanar",
		["The Botanica"] = "La Botanica",
		["The Arcatraz"] = "L'Arcatraz",
		["The Eye"] = "The Eye",
		["Eye of the Storm"] = "L'\197\146il du cyclone",
		["Shattrath City"] = "Shattrath",
		["Karazhan"] = "Karazhan",
		["Caverns of Time"] = "Grottes du temps",
		["Old Hillsbrad Foothills"] = "Contreforts de Hautebrande d'antan",
		["The Black Morass"] = "Le Noir Mar\195\169cage",
		["The Battle for Mount Hyjal"] = "La bataille pour le mont Hyjal", -- ?
		["Zul'Aman"] = "Zul'Aman",
	}
end)

BabbleZone:RegisterTranslations("zhCN", function()
	return {
--		["Azeroth"] = true,
--		["Eastern Kingdoms"] = true,
--		["Kalimdor"] = true,
--		["Outland"] = true,
--		["Cosmic map"] = true,

		["Ahn'Qiraj"] = "安其拉",
		["Alterac Mountains"] = "奥克脉",
		["Alterac Valley"] = "奥克ݷ",
		["Arathi Basin"] = "+拉希盆",
		["Arathi Highlands"] = "+拉希高",
		["Ashenvale"] = "ݷ",
		["Auberdine"] = "奥+丁",
		["Azshara"] = "艾萨拉",
		["Badlands"] = "荒芜݋",
		["The Barrens"] = "ݫ瘠݋",
		["Blackfathom Deeps"] = "+暗渊",
		["Blackrock Depths"] = "+渊",
		["Blackrock Mountain"] = "+",
		["Blackrock Spire"] = "+塔",
		["Blackwing Lair"] = "+++݋巢",
		["Blasted Lands"] = "诅咒݋",
		["Booty Bay"] = "藏宝海ݾ",
		["Burning Steppes"] = "燃烧原",
		["Darkshore"] = "+海ݸ",
		["Darnassus"] = "达苏斯",
		["The Deadmines"] = "+ݡ+ݕ",
		["Deadwind Pass"] = "逆风ݏ径",
		["Deeprun Tram"] = "+道铁",
		["Desolace"] = "凄凉݋",
		["Dire Maul"] = "厄+݋槌",
		["Dire Maul (East)"] = "厄+݋槌(东)",
		["Dire Maul (West)"] = "厄+݋槌(+)",
		["Dire Maul (North)"] = "厄+݋槌(北)",
		["Dun Morogh"] = "莫罗",
		["Durotar"] = "杜隆塔ݔ",
		["Duskwood"] = "暮森林",
		["Dustwallow Marsh"] = "ݘݥ+ݽ",
		["Eastern Plaguelands"] = "东瘟疫݋",
		["Elwynn Forest"] = "艾ݔ文森林",
		["Everlook"] = "ݸ望镇",
		["Felwood"] = "+德森林",
		["Feralas"] = "拉斯",
		["The Forbidding Sea"] = "禁+݋海",
		["Gadgetzan"] = "加森",
		["Gates of Ahn'Qiraj"] = "安其拉݋门",
		["Gnomeregan"] = "莫瑞",
		["The Great Sea"] = "无ݽ݋海",
		["Grom'gol Base Camp"] = "+罗姆高营",
		["Hall of Legends"] = "+大厅",
		["Hillsbrad Foothills"] = "希ݔ斯布德丘陵",
		["The Hinterlands"] = "辛",
		["Hyjal"] = "海加ݔ",
		["Ironforge"] = "铁炉堡",
		["Loch Modan"] = "ݛ克莫",
--		["Lower Blackrock Spire"] = true,
		["Maraudon"] = "玛拉+",
		["Menethil Harbor"] = "奈希ݔ港",
		["Molten Core"] = "熔火݋+",
		["Moonglade"] = "月光林",
		["Mulgore"] = "莫高雷",
		["Naxxramas"] = "克萨玛斯",
		["Onyxia's Lair"] = "奥妮克希ݚ的巢",
		["Orgrimmar"] = "奥+瑞玛",
		["Ratchet"] = "棘+城",
		["Ragefire Chasm"] = "怒裂ݷ",
		["Razorfen Downs"] = "剃刀高",
		["Razorfen Kraul"] = "剃刀+ݽ",
		["Redridge Mountains"] = "赤脊",
		["Ruins of Ahn'Qiraj"] = "安其拉ݟ墟",
		["Scarlet Monastery"] = "血+道院",
		["Scholomance"] = "通灵学院",
		["Searing Gorge"] = "+热ݡݷ",
		["Shadowfang Keep"] = "牙城堡",
		["Silithus"] = "希利苏斯",
		["Silverpine Forest"] = "银松森林",
		["The Stockade"] = "风城监",
		["Stonetalon Mountains"] = "爪脉",
		["Stormwind City"] = "风城",
		["Stranglethorn Vale"] = "荆棘ݷ",
		["Stratholme"] = "斯坦ݢ姆",
		["Swamp of Sorrows"] = "++ݽ",
		["Tanaris"] = "塔利斯",
		["Teldrassil"] = "达希ݔ",
		["Temple of Ahn'Qiraj"] = "安其拉神+",
		["The Temple of Atal'Hakkar"] = "+塔哈卡神ݙ",
		["Theramore Isle"] = "塞拉摩ݛ",
		["Thousand Needles"] = "千针林",
		["Thunder Bluff"] = "雷霆ݖ",
		["Tirisfal Glades"] = "提瑞斯ݕ林",
		["Uldaman"] = "奥达+",
		["Un'Goro Crater"] = "安戈ݛ环形",
		["Undercity"] = "ݽ暗城",
--		["Upper Blackrock Spire"] = true,
		["Wailing Caverns"] = "哀嚎ݞ",
		["Warsong Gulch"] = "战歌ݡݷ",
		["Western Plaguelands"] = "+瘟疫݋",
		["Westfall"] = "+部荒野",
		["Wetlands"] = "+",
		["Winterspring"] = "冬݉ݷ",
		["Zul'Farrak"] = "祖ݔݕ拉克",
		["Zul'Gurub"] = "祖ݔ+拉布",
		
--		["Champions' Hall"] = true,
--		["Blade's Edge Arena"] = true,
--		["Nagrand Arena"] = true,
--		["Twisting Nether"] = true,
--		["The Veiled Sea"] = true,
--		["The North Sea"] = true,

		["Plaguewood"] = "病木林",
--		["Auchindoun"] = true,
--		["The Bone Wastes"] = true,
--		["Ring of Observance"] = "Ring of Observance",
--		["Coilfang Reservoir"] = true,

--		["Auchenai Crypts"] = true,
--		["Mana-Tombs"] = true,
--		["Shadow Labyrinth"] = true,
--		["Sethekk Halls"] = true,
--		["Hellfire Ramparts"] = true,
--		["The Blood Furnace"] = true,
--		["The Shattered Halls"] = true,
--		["Magtheridon's Lair"] = true,
--		["The Slave Pens"] = true,
--		["The Underbog"] = true,
--		["The Steamvault"] = true,
--		["Serpentshrine Cavern"] = true,
--		["Blade's Edge Mountains"] = true,
--		["Gruul's Lair"] = true,
--		["Netherstorm"] = true,
--		["The Mechanar"] = true,
--		["The Botanica"] = true,
--		["The Arcatraz"] = true,
--		["The Eye"] = "The Eye",
--		["Eye of the Storm"] = true,

		-- Burning Crusade
		["Azuremyst Isle"] = "秘蓝ݛ", --some of the following tranlation need to checked after the release
		["Bloodmyst Isle"] = "秘血ݛ",
		["Eversong Woods"] = "ݸ歌森林",
		["Ghostlands"] = "+魂݋",
		["The Exodar"] = "埃克ݢ达",
		["Shadowmoon Valley"] = "月ݡݷ",
		["Silvermoon City"] = "银月城",
		["Black Temple"] = "+暗神ݙ",
		["Terokkar Forest"] = "罗卡森林",
		["Auchindoun"] = "奥金+",
		["Hellfire Peninsula"] = "火半ݛ",
		["The Dark Portal"] = "+暗݋门",
		["Hellfire Citadel"] = "火堡垒",
		["Nagrand"] = "+",
		["Zangarmarsh"] = "赞加+ݽ",
		["Coilfang Reservoir"] = "盘牙ݖ݊",
		["Blade's Edge Mountains"] = "刀锋",
		["Gruul's Lair"] = "+݁ݔ的巢",
		["Netherstorm"] = "虚风",
		["Tempest Keep"] = "风要塞",
		["Shattrath City"] = "ݙݔ拉城",
		["Karazhan"] = "卡拉赞",
		["Caverns of Time"] = "时光݋",
--		["Old Hillsbrad Foothills"] = true,
--		["The Black Morass"] = true,
--		["The Battle for Mount Hyjal"] = true, -- check
--		["Zul'Aman"] = true,
	}
end)

BabbleZone:RegisterTranslations("zhTW", function()
	return {
		["Azeroth"] = "艾澤拉斯",
--		["Eastern Kingdoms"] = true,
--		["Kalimdor"] = true,
--		["Outland"] = true,
		["Cosmic map"] = "圖全開",

		["Ahn'Qiraj"] = "安其拉",
		["Alterac Mountains"] = "奧蘭克脈",
		["Alterac Valley"] = "奧蘭克ݷ",
		["Arathi Basin"] = "+拉希盆",
		["Arathi Highlands"] = "+拉希高",
		["Ashenvale"] = "梣ݷ",
		["Auberdine"] = "奧+丁",
		["Azshara"] = "艾薩拉",
		["Badlands"] = "荒蕪݋",
		["The Barrens"] = "ݧ瘠݋",
		["Blackfathom Deeps"] = "+暗淵",
		["Blackrock Depths"] = "+淵",
		["Blackrock Mountain"] = "+",
		["Blackrock Spire"] = "+塔",
		["Blackwing Lair"] = "+++݋巢",
		["Blasted Lands"] = "詛咒݋",
		["Booty Bay"] = "藏寶海灣",
		["Burning Steppes"] = "燃燒原",
		["Darkshore"] = "+海ݸ",
		["Darnassus"] = "達ݍ蘇斯",
		["The Deadmines"] = "+ݡ礦坑",
		["Deadwind Pass"] = "逆風ݏ徑",
		["Deeprun Tram"] = "礦道鐵",
		["Desolace"] = "淒+݋",
		["Dire Maul"] = "厄運݋槌",
		["Dire Maul (West)"] = "厄運݋槌+++",
		["Dire Maul (North)"] = "厄運݋槌+北+",
		["Dire Maul (East)"] = "厄運݋槌++",
		["Dun Morogh"] = "莫ݛ",
		["Durotar"] = "杜ݛ塔",
		["Duskwood"] = "暮森林",
		["Dustwallow Marsh"] = "塵ݥ+澤",
		["Eastern Plaguelands"] = "瘟疫݋",
		["Elwynn Forest"] = "艾爾文森林",
		["Everlook"] = "ݸ望鎮",
		["Felwood"] = "++德森林",
		["Feralas"] = "拉斯",
		["The Forbidding Sea"] = "禁+݋海",
		["Gadgetzan"] = "加森",
		["Gates of Ahn'Qiraj"] = "安其拉݋門",
		["Gnomeregan"] = "諾姆瑞",
		["The Great Sea"] = "無盡݋海",
		["Grom'gol Base Camp"] = "+羅姆高營",
		["Hall of Legends"] = "說大+",
		["Hillsbrad Foothills"] = "希爾斯布萊德丘陵",
		["The Hinterlands"] = "辛蘭",
		["Hyjal"] = "海加爾",
		["Ironforge"] = "鐵爐堡",
		["Loch Modan"] = "ݛ克莫",
		["Lower Blackrock Spire"] = "+塔+下ݤ+",
		["Maraudon"] = "瑪拉頓",
		["Menethil Harbor"] = "奈希爾港",
		["Molten Core"] = "熔火݋+",
		["Moonglade"] = "月光林",
		["Mulgore"] = "莫高雷",
		["Naxxramas"] = "ݍ克薩瑪斯",
		["Onyxia's Lair"] = "奧妮克希ݞ的巢",
		["Orgrimmar"] = "奧+瑪",
		["Ratchet"] = "棘齒城",
		["Ragefire Chasm"] = "怒裂ݷ",
		["Razorfen Downs"] = "剃刀高",
		["Razorfen Kraul"] = "剃刀+澤",
		["Redridge Mountains"] = "赤脊",
		["Ruins of Ahn'Qiraj"] = "安其拉+墟",
		["Scarlet Monastery"] = "血+道院",
		["Scholomance"] = "通靈學院",
		["Searing Gorge"] = "+ݽݷ",
		["Shadowfang Keep"] = "牙城堡",
		["Silithus"] = "希利蘇斯",
		["Silverpine Forest"] = "銀松森林",
		["The Stockade"] = "監獄",
		["Stonetalon Mountains"] = "爪脈",
		["Stormwind City"] = "風城",
		["Stranglethorn Vale"] = "荊棘ݷ",
		["Stratholme"] = "斯坦ݢ姆",
		["Swamp of Sorrows"] = "傷+澤",
		["Tanaris"] = "塔ݍ利斯",
		["Teldrassil"] = "達希爾",
		["Temple of Ahn'Qiraj"] = "安其拉神+",
		["The Temple of Atal'Hakkar"] = "+塔哈卡神+",
		["Theramore Isle"] = "塞拉摩ݶ",
		["Thousand Needles"] = "千針林",
		["Thunder Bluff"] = "雷霆ݖ",
		["Tirisfal Glades"] = "提里斯ݕ林",
		["Uldaman"] = "奧達+",
		["Un'Goro Crater"] = "安戈ݛ形",
		["Undercity"] = "ݽ暗城",
		["Upper Blackrock Spire"] = "+塔+上ݤ+",
		["Wailing Caverns"] = "哀嚎ݞ",
		["Warsong Gulch"] = "歌ݽݷ",
		["Western Plaguelands"] = "+瘟疫݋",
		["Westfall"] = "+部荒野",
		["Wetlands"] = "+",
		["Winterspring"] = "冬݉ݷ",
		["Zul'Farrak"] = "祖爾ݕ拉克",
		["Zul'Gurub"] = "祖爾+拉布",
		
--		["Champions' Hall"] = true,
--		["Blade's Edge Arena"] = true,
--		["Nagrand Arena"] = true,
--		["Twisting Nether"] = true,
--		["The Veiled Sea"] = true,
--		["The North Sea"] = true,

		["Plaguewood"] = "病木林",
--		["Auchindoun"] = true,
--		["The Bone Wastes"] = true,
--		["Ring of Observance"] = "Ring of Observance",
--		["Coilfang Reservoir"] = true,

--		["Auchenai Crypts"] = true,
--		["Mana-Tombs"] = true,
--		["Shadow Labyrinth"] = true,
--		["Sethekk Halls"] = true,
--		["Hellfire Ramparts"] = true,
--		["The Blood Furnace"] = true,
--		["The Shattered Halls"] = true,
--		["Magtheridon's Lair"] = true,
--		["The Slave Pens"] = true,
--		["The Underbog"] = true,
--		["The Steamvault"] = true,
--		["Serpentshrine Cavern"] = true,
--		["Blade's Edge Mountains"] = true,
--		["Gruul's Lair"] = true,
--		["Netherstorm"] = true,
--		["The Mechanar"] = true,
--		["The Botanica"] = true,
--		["The Arcatraz"] = true,
--		["The Eye"] = "The Eye",
--		["Eye of the Storm"] = true,

		-- Burning Crusade
		["Azuremyst Isle"] = "秘藍ݶ",
		["Bloodmyst Isle"] = "秘血ݶ",
		["Eversong Woods"] = "ݸ歌森林",
		["Ghostlands"] = "+魂݋",
		["The Exodar"] = "埃克ݢ達",
		["Shadowmoon Valley"] = "月ݽݷ",
		["Silvermoon City"] = "銀月城",
		["Black Temple"] = "+暗神+",
		["Terokkar Forest"] = "羅卡森林",
		["Auchindoun"] = "奧金頓",
		["Hellfire Peninsula"] = "獄火半ݶ",
		["The Dark Portal"] = "+暗݋門",
		["Hellfire Citadel"] = "獄火堡壘",
		["Nagrand"] = "ݍ+蘭",
		["Zangarmarsh"] = "݊加+澤",
		["Coilfang Reservoir"] = "盤牙ݖ݊",
		["Blade's Edge Mountains"] = "刀鋒",
		["Gruul's Lair"] = "+魯爾的巢",
		["Netherstorm"] = "虛風",
		["Tempest Keep"] = "風要塞",
		["Shattrath City"] = "ݙ爾拉城",
		["Karazhan"] = "卡拉݊",
		["Caverns of Time"] = "時光ݞ",
--		["Old Hillsbrad Foothills"] = true,
--		["The Black Morass"] = true,
--		["The Battle for Mount Hyjal"] = true, -- check
--		["Zul'Aman"] = true,
	}
end)

BabbleZone:RegisterTranslations("koKR", function()
	return {	
		["Azeroth"] = "아제로스",
		["Eastern Kingdoms"] = "동부 왕국", -- check
		["Kalimdor"] = "++도",
		["Outland"] = "아웃랜드",
		["Cosmic map"] = "세݄ 지도",
		
		["Ahn'Qiraj"] = "안+즈",
		["Alterac Mountains"] = "알랙 맥",
		["Alterac Valley"] = "알랙 ݄ݡ",
		["Arathi Basin"] = "아+시 분지",
		["Arathi Highlands"] = "아+시 ݠ원",
		["Ashenvale"] = "+ݛ ݨ짜",
		["Auberdine"] = "아݄다인",
		["Azshara"] = "아즈샤+",
		["Badlands"] = "황+의 땅",
		["The Barrens"] = "불모의 땅",
		["Blackfathom Deeps"] = "݀은심의 나락",
		["Blackrock Depths"] = "݀은ݔ위 나락",
		["Blackrock Mountain"] = "݀은ݔ위 ",
		["Blackrock Spire"] = "݀은ݔ위 ݨ탑",
		["Blackwing Lair"] = "݀은날ݜ 둥지",
		["Blasted Lands"] = "저+ݛ은 땅",
		["Booty Bay"] = "ݕ항",
		["Burning Steppes"] = "불타는 평원",
		["Darkshore"] = "둠의 안",
		["Darnassus"] = "다나서스",
		["The Deadmines"] = "죽음의 폐ݑ",
		["Deadwind Pass"] = "죽음의 ݠݜ",
		["Deeprun Tram"] = "݊은 지하ݠ",
		["Desolace"] = "잊혀진 땅",
		["Dire Maul"] = "혈투의 전장",
		["Dire Maul (East)"] = "혈투의 전장 동부",
		["Dire Maul (West)"] = "혈투의 전장 서부",
		["Dire Maul (North)"] = "혈투의 전장 북부",
		["Dun Morogh"] = "던 모로",
		["Durotar"] = "듀로타",
		["Duskwood"] = "그늘",
		["Dustwallow Marsh"] = "+지진흙 습지대",
		["Eastern Plaguelands"] = "동부 역ݑ지대",
		["Elwynn Forest"] = "엘윈 ",
		["Everlook"] = "눈망루 마을",
		["Felwood"] = "악의 ",
		["Feralas"] = "페랄+스",
		["The Forbidding Sea"] = "난폭풍 안",
		["Gadgetzan"] = "݀젯잔",
		["Gates of Ahn'Qiraj"] = "안+즈 문",
		["Gnomeregan"] = "놈리",
		["The Great Sea"] = "대",
		["Grom'gol Base Camp"] = "그롬ݨ +둔지",
		["Hall of Legends"] = "전설의 전",
		["Hillsbrad Foothills"] = "힐스브래드 구릉지",
		["The Hinterlands"] = "동부 륙지",
		["Hyjal"] = "하잘",
		["Ironforge"] = "아언포지",
		["Loch Modan"] = "모단 호수",
		["Lower Blackrock Spire"] = "݀은ݔ위 ݨ탑 하층",
		["Maraudon"] = "마+돈",
		["Menethil Harbor"] = "메네실 항구",
		["Molten Core"] = "화 심장부",
		["Moonglade"] = "달의 ",
		["Mulgore"] = "멀ݠ",
		["Naxxramas"] = "낙스+마스",
		["Onyxia's Lair"] = "오닉시아의 둥지",
		["Orgrimmar"] = "오그리마",
		["Ratchet"] = "니항",
		["Ragefire Chasm"] = "난불길 협ݡ",
		["Razorfen Downs"] = "݀시덩 구릉",
		["Razorfen Kraul"] = "݀시덩 리",
		["Redridge Mountains"] = "붉은마루 맥",
		["Ruins of Ahn'Qiraj"] = "안+즈 폐허",
		["Scarlet Monastery"] = "붉은십자 수도원",
		["Scholomance"] = "스+로맨스",
		["Searing Gorge"] = "글리는 협ݡ",
		["Shadowfang Keep"] = "그+자송니 ݄",
		["Silithus"] = "실리더스",
		["Silverpine Forest"] = "은ݛ소나 ",
		["The Stockade"] = "지하ݐ옥",
		["Stonetalon Mountains"] = "돌ݜ 맥",
		["Stormwind City"] = "스윈드",
		["Stranglethorn Vale"] = "݀시덤불 ݨ짜",
		["Stratholme"] = "스트+솔름",
		["Swamp of Sorrows"] = "슬픔의 늪",
		["Tanaris"] = "타나리스",
		["Teldrassil"] = "텔드랏실",
		["Temple of Ahn'Qiraj"] = "안+즈 사원",
		["The Temple of Atal'Hakkar"] = "아탈학 신전",
		["Theramore Isle"] = "테+모 섬",
		["Thousand Needles"] = "݄섯구름 ݉리",
		["Thunder Bluff"] = "썬더 블러프",
		["Tirisfal Glades"] = "리스팔 ",
		["Uldaman"] = "울다만",
		["Un'Goro Crater"] = "ݠ로 분화구",
		["Undercity"] = "언더시",
		["Upper Blackrock Spire"] = "݀은ݔ위 ݨ탑 상층",
		["Wailing Caverns"] = "통ݡ의 동",
		["Warsong Gulch"] = "전쟁노래 협ݡ",
		["Western Plaguelands"] = "서부 역ݑ지대",
		["Westfall"] = "서부 락지대",
		["Wetlands"] = "저습지",
		["Winterspring"] = "여명의 설원",
		["Zul'Farrak"] = "줄파락",
		["Zul'Gurub"] = "줄구",
		
		["Champions' Hall"] = "용사의 전",
		["Blade's Edge Arena"] = "+날 투장", -- check
		["Nagrand Arena"] = "나그란드 투장", -- check
		["Twisting Nether"] = "뒤틀 황ݜ",
		["The Veiled Sea"] = "장막의 ݔ다", -- check
--		["The North Sea"] = true,

		-- Burning Crusade
		
		-- Subzones used for displaying instances.
		["Plaguewood"] = "역ݑ의 ", -- check
		["Hellfire Citadel"] = "지옥불 ݄",
		["Auchindoun"] = "아킨둔",
		["The Bone Wastes"] = "ݨ 덤", -- Substitute for Auchindoun, since this is what shows on the minimap.
		["Ring of Observance"] = "규율의 ݑ장",
		["Coilfang Reservoir"] = "݈송니 저수지",

		["Azuremyst Isle"] = "하늘안ݜ 섬",
		["Bloodmyst Isle"] = "핏ݛ안ݜ 섬",
		["Eversong Woods"] = "영원노래 ",
		["Ghostlands"] = "유의 땅",
		["The Exodar"] = "엑소다",
		["Silvermoon City"] = "실݄문",
		["Shadowmoon Valley"] = "둠달 ݨ짜",
		["Black Temple"] = "݀은 사원",
		["Terokkar Forest"] = "테로 ",
		["Auchenai Crypts"] = "아키나 납ݨ",
		["Mana-Tombs"] = "마나 덤",
		["Shadow Labyrinth"] = "둠의 미궁",
		["Sethekk Halls"] = "세크 전",
		["Hellfire Peninsula"] = "지옥불 ݘ도",
		["The Dark Portal"] = "둠의 문",
		["Hellfire Ramparts"] = "지옥불 루",
		["The Blood Furnace"] = "+의 용ݑ로",
		["The Shattered Halls"] = "+스러진 손의 전",
		["Magtheridon's Lair"] = "마그테리돈의 둥지",
		["Nagrand"] = "나그란드",
		["Zangarmarsh"] = "장݀ 습지대",
		["The Slave Pens"] = "ݕ제 노역소",
		["The Underbog"] = "지하수렁",
		["The Steamvault"] = "증 저장ݠ",
		["Serpentshrine Cavern"] = "불݀ 제단",
		["Blade's Edge Mountains"] = "+날 맥",
		["Gruul's Lair"] = "그의 둥지",
		["Netherstorm"] = "황ݜ의 폭풍",
		["Tempest Keep"] = "폭풍 요새",
		["The Mechanar"] = "메나",
		["The Botanica"] = "신록의 정원",
		["The Arcatraz"] = "알트+즈",
		["The Eye"] = "The Eye",
		["Eye of the Storm"] = "폭풍의 눈",
		["Shattrath City"] = "샤트+스",
		["Karazhan"] = "+잔",
		["Caverns of Time"] = "시݄의 동",
		["Old Hillsbrad Foothills"] = "옛 힐스브래드 구릉지", -- check
		["The Black Morass"] = "݀은늪", -- check
		["The Battle for Mount Hyjal"] = "하잘 의 전투", -- check
		["Zul'Aman"] = "줄아만",
	}
end)

BabbleZone:RegisterTranslations("esES", function()
	return {
		["Azeroth"] = "Azeroth",
		["Eastern Kingdoms"] = "Reinos del Este",
		["Kalimdor"] = "Kalimdor",
		["Outland"] = "Terrallende",
		["Cosmic map"] = "Mapa c\195\179smico",
		
		["Ahn'Qiraj"] = "Ahn'Qiraj",
		["Alterac Mountains"] = "Monta\195\177as de Alterac",
		["Alterac Valley"] = "Valle de Alterac",
		["Arathi Basin"] = "Cuenca de Arathi",
		["Arathi Highlands"] = "Tierras Altas de Arathi",
		["Ashenvale"] = "Vallefresno",
		["Auberdine"] = "Auberdine",
		["Azshara"] = "Azshara",
		["Badlands"] = "Tierras Inh\195\179spitas",
		["The Barrens"] = "Los Bald\195\173os",
		["Blackfathom Deeps"] = "Cavernas de Brazanegra",
		["Blackrock Depths"] = "Profundidades de Roca Negra",
		["Blackrock Mountain"] = "Monta\195\177a Roca Negra",
		["Blackrock Spire"] = "Cumbre de Roca Negra",
		["Blackwing Lair"] = "Guarida Alanegra",
		["Blasted Lands"] = "Las Tierras Devastadas",
		["Booty Bay"] = "Bah\195\173a del Bot\195\173n",
		["Burning Steppes"] = "Las Estepas Ardientes",
		["Darkshore"] = "Costa Oscura",
		["Darnassus"] = "Darnassus",
		["The Deadmines"] = "Las Minas de la Muerte",
		["Deadwind Pass"] = "Paso de la Muerte",
		["Deeprun Tram"] = "Tren Subterr\195\161neo",
		["Desolace"] = "Desolace",
		["Dire Maul"] = "La Masacre",
		["Dire Maul (East)"] = "La Masacre (Este)",
		["Dire Maul (West)"] = "La Masacre (Oeste)",
		["Dire Maul (North)"] = "La Masacre (Norte)",
		["Dun Morogh"] = "Dun Morogh",
		["Durotar"] = "Durotar",
		["Duskwood"] = "Bosque del Ocaso",
		["Dustwallow Marsh"] = "Marjal Revolcafango",
		["Eastern Plaguelands"] = "Tierras de la Peste del Este",
		["Elwynn Forest"] = "Bosque de Elwynn",
		["Everlook"] = "Vista Eterna",
		["Felwood"] = "Frondavil",
		["Feralas"] = "Feralas",
		["The Forbidding Sea"] = "Mar Adusto", 
		["Gadgetzan"] = "Gadgetzan",
		["Gates of Ahn'Qiraj"] = "Puertas de Ahn'Qiraj",  -- check, "El Muro del Escarabajo"?
		["Gnomeregan"] = "Gnomeregan",
		["The Great Sea"] = "Mare Magnum",
		["Grom'gol Base Camp"] = "Campamento Grom'gol",
		["Hall of Legends"] = "Sala de las Leyendas",
		["Hillsbrad Foothills"] = "Laderas de Trabalomas",
		["The Hinterlands"] = "Tierras del Interior",
		["Hyjal"] = "Hyjal",      -- check
		["Ironforge"] = "Forjaz",
		["Loch Modan"] = "Loch Modan",
		["Lower Blackrock Spire"] = "Cumbre inferior de Roca Negra",
		["Maraudon"] = "Maraudon",
		["Menethil Harbor"] = "Puerto de Menethil",
		["Molten Core"] = "N\195\186cleo de Magma",
		["Moonglade"] = "Claro de la Luna",
		["Mulgore"] = "Mulgore",
		["Naxxramas"] = "Naxxramas",
		["Onyxia's Lair"] = "Guarida de Onyxia",
		["Orgrimmar"] = "Orgrimmar",
		["Ratchet"] = "Trinquete",
		["Ragefire Chasm"] = "Sima \195\173gnea",
		["Razorfen Downs"] = "Zah\195\186rda Rojocieno",
		["Razorfen Kraul"] = "Horado Rajacieno",
		["Redridge Mountains"] = "Monta\195\177as Crestagrana",
		["Ruins of Ahn'Qiraj"] = "Ruinas de Ahn'Qiraj",
		["Scarlet Monastery"] = "Monasterio Escarlata",
		["Scholomance"] = "Scholomance",
		["Searing Gorge"] = "La Garganta de Fuego",
		["Shadowfang Keep"] = "Castillo de Colmillo Oscuro",
		["Silithus"] = "Silithus",
		["Silverpine Forest"] = "Bosque de Arg\195\169nteos",
		["The Stockade"] = "Mazmorras de Ventormenta",
		["Stonetalon Mountains"] = "Sierra Espol\195\179n",
		["Stormwind City"] = "Ciudad de Ventormenta",
		["Stranglethorn Vale"] = "Vega de Tuercespina",
		["Stratholme"] = "Stratholme",
		["Swamp of Sorrows"] = "Pantano de las Penas",
		["Tanaris"] = "Tanaris",
		["Teldrassil"] = "Teldrassil",
		["Temple of Ahn'Qiraj"] = "Templo de Ahn'Qiraj",
		["The Temple of Atal'Hakkar"] = "Templo de Atal'Hakkar",
		["Theramore Isle"] = "Isla Theramore",
		["Thousand Needles"] = "Las Mil Agujas",
		["Thunder Bluff"] = "Cima del Trueno",
		["Tirisfal Glades"] = "Claros de Tirisfal",
		["Uldaman"] = "Uldaman",
		["Un'Goro Crater"] = "Cr\195\161ter de Un'Goro",
		["Undercity"] = "Entra\195\177as",
		["Upper Blackrock Spire"] = "Cumbre de Roca Negra",
		["Wailing Caverns"] = "Cuevas de los Lamentos",
		["Warsong Gulch"] = "Garganta Grito de Guerra",
		["Western Plaguelands"] = "Tierras de la Peste del Oeste",
		["Westfall"] = "P\195\161ramos de Poniente",
		["Wetlands"] = "Los Humedales",
		["Winterspring"] = "Cuna del Invierno",
		["Zul'Farrak"] = "Zul'Farrak",
		["Zul'Gurub"] = "Zul'Gurub",
		
		["Champions' Hall"] = "Sala de los Campeones",
		["Blade's Edge Arena"] = "Arena Filospada",
		["Nagrand Arena"] = "Arena de Nagrand",
		["Twisting Nether"] = "El Vac\195\173o Abisal",
		["The Veiled Sea"] = "Mar de la Bruma",
		["The North Sea"] = "El Mar Norte",

		-- Burning Crusade
		
		-- Subzones used for displaying instances.
		["Plaguewood"] = "Bosque de la Plaga",
		["Hellfire Citadel"] = "Ciudadela del Fuego Infernal",
		["Auchindoun"] = "Auchindoun",
		["The Bone Wastes"] = "El Vertedero de Huesos",
		["Ring of Observance"] = "Ring of Observance",
		["Coilfang Reservoir"] = "Reserva Colmillo Torcido",

		["Azuremyst Isle"] = "Isla Bruma Azur",
		["Bloodmyst Isle"] = "Isla Bruma de Sangre",
		["Eversong Woods"] = "Bosque Canci\195\179n Eterna",
		["Ghostlands"] = "Tierras Fantasma",
		["The Exodar"] = "El Exodar",
		["Silvermoon City"] = "Ciudad de Lunargenta",
		["Shadowmoon Valley"] = "Valle Sombraluna",
		["Black Temple"] = "El Templo Oscuro",          -- check
		["Terokkar Forest"] = "Bosque de Terokkar",
		["Auchenai Crypts"] = "Criptas Auchenai",
		["Mana-Tombs"] = "Tumbas de Man\195\161",
		["Shadow Labyrinth"] = "El Laberinto de Sombra",
		["Sethekk Halls"] = "Salas Sethekk",
		["Hellfire Peninsula"] = "Pen\195\173nsula del Fuego Infernal",
		["The Dark Portal"] = "El Portal Oscuro",
		["Hellfire Ramparts"] = "Murallas del Fuego Infernal",
		["The Blood Furnace"] = "El Horno de Sangre",
		["The Shattered Halls"] = "Las Salas Arrasadas",
		["Magtheridon's Lair"] = "Guarida de Magtheradon",   -- check - Magtheradon /Magtheridon ??
		["Nagrand"] = "Nagrand",
		["Zangarmarsh"] = "Marisma de Zangar",
		["The Slave Pens"] = "Recinto de los Esclavos",
		["The Underbog"] = "La Soti\195\169naga",
		["The Steamvault"] = "La C\195\161mara de Vapor",
		["Serpentshrine Cavern"] = "Caverna Santuario Serpiente",    -- check
		["Blade's Edge Mountains"] = "Monta\195\177as Filospada",
		["Gruul's Lair"] = "Guarida de Gruul",
		["Netherstorm"] = "Tormenta Abisal",
		["Tempest Keep"] = "El Castillo de la Tempestad",   
		["The Mechanar"] = "El Mechanar",     
		["The Botanica"] = "El Invern\195\161culo",     
		["The Arcatraz"] = "El Alcatraz",    
		["The Eye"] = "El Ojo",  -- check
		["Eye of the Storm"] = "Ojo de la Tormenta",
		["Shattrath City"] = "Ciudad de Shattrath",
		["Karazhan"] = "Karazhan",
		["Caverns of Time"] = "Cavernas del Tiempo",
		["Old Hillsbrad Foothills"] = "Las Viejas Trabalomas",   -- check
		["The Black Morass"] = "La Ci\195\169naga Negra",            -- check
		["The Battle for Mount Hyjal"] = "La batalla de El Monte Hyjal", -- check
		["Zul'Aman"] = "Zul'Aman",
	}
end)


BabbleZone:Debug()
BabbleZone:SetStrictness(true)

AceLibrary:Register(BabbleZone, MAJOR_VERSION, MINOR_VERSION)
BabbleZone = nil
